BioFileHandlerConfig class

Constructors

BioFileHandlerConfig({required bool failOnConflict, required bool checkFileConsistency, required bool allowParallelExecution, required int parallelExecutionThreshold, required int numberThreads})
BioFileHandlerConfig.parallelDefaultConfig()
BioFileHandlerConfig.serialDefaultConfig()

Properties

allowParallelExecution bool
final
checkFileConsistency bool
final
failOnConflict bool
final
hashCode int
The hash code for this object.
no setterinherited
numberThreads int
final
parallelExecutionThreshold int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({dynamic failOnConflict, dynamic checkFileConsistency, dynamic removeDuplicates, dynamic allowParallelExecution, dynamic parallelExecutionThreshold, dynamic numberThreads}) BioFileHandlerConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited