Sequence class abstract

Implementers

Constructors

Sequence(String seq)
Sequence.empty()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seq String
final

Methods

isEmpty() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
verify() bool

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

buildVerifiedFromString(String string) Sequence?
Returns either a AminoAcidSequence or NucleotideSequence based on the given string

Constants

aminoAcidToNucleotides → const Map<String, List<String>>