Protein class
Representation of a biological protein
The id is a unique string identifier for the protein, it can for example be a refseq, pdb or uniprot id. The sequence can be either amino acids or nucleotides. The embeddings, i.e. representations of the proteins, are encapsulated in the separate EmbeddingManager class. The taxonomy represents the most important information to classify the protein's species of origin. The attributes are other generic attributes that are not represented by the features above.
Constructors
- Protein(String id, {Sequence sequence = const AminoAcidSequence.empty(), EmbeddingManager embeddings = const EmbeddingManager.empty(), Taxonomy taxonomy = const Taxonomy.unknown(), CustomAttributes attributes = const CustomAttributes.empty()})
-
const
- Protein.empty()
-
const
Properties
- attributes → CustomAttributes
-
final
- embeddings → EmbeddingManager
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequence → Sequence
-
final
- taxonomy → Taxonomy
-
final
- typeName → String
-
no setteroverride
Methods
-
copyWith(
{dynamic id, dynamic sequence, dynamic embeddings, dynamic taxonomy, dynamic attributes}) → Protein -
getCustomAttributes(
) → CustomAttributes -
override
-
getEmbeddings(
) → EmbeddingManager -
override
-
getID(
) → String -
override
-
merge(
BioEntity other, {required bool failOnConflict}) → Protein -
Merge the values and attributes of this protein with another protein
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFastaHeader(
) → String - Create a fasta-type header for this protein
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
override
-
updateFromCustomAttributes<
T extends BioEntity> (CustomAttributes newAttributes) → T -
inherited
-
updateFromMap<
T extends BioEntity> (Map< String, String> map) → T -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited